@@ -5,6 +5,7 @@ from .select_cast_checker import SelectCastChecker
 from .chained_function_checker import ChainedDotFunctionsSyntaxChecker
 from .confluence_page_checker import ConfluencePageChecker
 from .author_checker import AuthorChecker
+from .import_checker import PySparkImportChecker
 
 def register(linter):
     linter.register_checker(FunctionCallChecker(linter))
@@ -14,3 +15,4 @@ def register(linter):
     linter.register_checker(ConfluencePageChecker(linter))
     linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
     linter.register_checker(AuthorChecker(linter))
+    linter.register_checker(PySparkImportChecker(linter))
